﻿using System.ComponentModel.Composition;
using System.Windows;
using System.Windows.Input;
using DataBrowser.IAppControllers;
using Microsoft.Practices.ServiceLocation;

namespace DataBrowser.ViewModel
{
    /// <summary>
    /// DefaultMenuViewModel handles the DefaultMenuView commands.
    /// </summary>
    [Export(typeof(DefaultMenuViewModel))]
    public class DefaultMenuViewModel : DependencyObject
    {
        #region Ctor.

        /// <summary>
        /// Constructor to Initialize the commands
        /// </summary>
        public DefaultMenuViewModel()
        {
            var controller = ServiceLocator.Current.GetInstance<IDefaultMenuControler>();
            OpenCommand = controller.OpenFileCommand;
            CloseCommand = controller.CloseCommand;            
        }

        #endregion Ctor.

        #region Commands.

        /// <summary>
        /// Delegate command for Open File.
        /// </summary>
        public ICommand OpenCommand
        {
            get { return (ICommand)this.GetValue(OpenRawFileCommand); }
            set { this.SetValue(OpenRawFileCommand, value); }
        }

        /// <summary>
        /// Using a DependencyProperty as the backing store for OpenRawFile.  This enables animation, styling, binding, etc...
        /// </summary>
        public static readonly DependencyProperty OpenRawFileCommand = DependencyProperty.Register(
                        "OpenCommand", typeof(ICommand), typeof(DefaultMenuViewModel), new PropertyMetadata((ICommand)null));


        /// <summary>
        /// Delegate command for close the current view and raw files.
        /// </summary>
        public ICommand CloseCommand
        {
            get { return (ICommand)GetValue(CloseCommandProperty); }
            set { SetValue(CloseCommandProperty, value); }
        }

        /// <summary>
        /// Using a DependencyProperty as the backing store for CloseCommand.  This enables animation, styling, binding, etc...
        /// </summary>
        public static readonly DependencyProperty CloseCommandProperty =
            DependencyProperty.Register("CloseCommand", typeof(ICommand), typeof(DefaultMenuViewModel), new PropertyMetadata((ICommand)null));

        #endregion Commands.
    }
}
